Client
======

AsyncDHIS2Client
----------------

.. autoclass:: pydhis2.core.client.AsyncDHIS2Client
   :members:
   :undoc-members:
   :show-inheritance:

SyncDHIS2Client
---------------

.. autoclass:: pydhis2.core.client.SyncDHIS2Client
   :members:
   :undoc-members:
   :show-inheritance:

Helper Functions
----------------

.. autofunction:: pydhis2.get_client

